<?php

namespace Drupal\drush_help\Utility;

/**
 * Provides module internal helper methods.
 *
 * @ingroup utility
 */
class InternalFunctions {

  /**
   * Return the drush command help html.
   *
   * @return string
   *   The drush command help html.
   */
  public static function getDrushCommandsHelp($drush_commands) {
    $section['drush_help'] = ['#markup' => '<h3>' . t('Drush commands') . '</h3>'];
    foreach ($drush_commands as $command => $definition) {
      // The details drush command element container.
      $section[$command] = [
        '#type' => 'details',
        '#title' => $command,
        '#description' => $definition['description'],
        '#open' => FALSE,
      ];

      // Examples.
      if (isset($definition['examples'])) {
        $rows = [];
        // Iterating over each example.
        foreach ($definition['examples'] as $example_command => $section_definition) {
          $rows[] = [$example_command, $section_definition];
        }
        // Examples render array.
        $section[$command]['examples'] = [
          '#type' => 'table',
          '#caption' => t('Examples'),
          '#header' => [
            t('Command'),
            [
              'data' => t('Description'),
              // Hidding the description on narrow width devices.
              'class' => [RESPONSIVE_PRIORITY_MEDIUM],
            ],
          ],
          '#rows' => $rows,
          '#sticky' => TRUE,
        ];
      }

      // Arguments.
      if (isset($definition['arguments'])) {
        $rows = [];
        // Iterating over each argument.
        foreach ($definition['arguments'] as $example_command => $section_definition) {
          // Sometimes we can have links in the drush descriptions, so we need
          // to extract it and convert it in links (in the Drupal way) to be
          // displayed in the Drupal interface.
          // Searching if the description have links inside to convert it.
          $section_definition = UrlHelper::convertPlainUrlInLink($section_definition);

          $rows[] = [$example_command, $section_definition];
        }
        // Arguments render array.
        $section[$command]['arguments'] = [
          '#type' => 'table',
          '#caption' => t('Arguments'),
          '#header' => [t('Name'), t('Description')],
          '#rows' => $rows,
          '#sticky' => TRUE,
        ];
      }

      // Options.
      if (isset($definition['options'])) {
        $rows = [];
        // Iterating over each option.
        foreach ($definition['options'] as $example_command => $section_definition) {
          $example_command = '--' . $example_command;
          // Verifying that we have example-value.
          if (isset($section_definition['example-value'])) {
            // Checking for the value.
            switch ($section_definition['value']) {
              case 'optional':
                $example_command .= '=[' . $section_definition['example-value'] . ']';
                break;

              // By default is required.
              default:
                $example_command .= '=<' . $section_definition['example-value'] . '>';
            }
          }
          // Sometimes we can have links in the drush descriptions, so we need
          // to extract it and convert it in links (in the Drupal way) to be
          // displayed in the Drupal interface.
          // Searching if the description have links inside to convert it.
          $section_definition['description'] = UrlHelper::convertPlainUrlInLink($section_definition['description']);

          $rows[] = [$example_command, $section_definition['description']];
        }
        // Options render array.
        $section[$command]['options'] = [
          '#type' => 'table',
          '#caption' => t('Options'),
          '#header' => [t('Name'), t('Description')],
          '#rows' => $rows,
          '#sticky' => TRUE,
        ];
      }

      // Alias.
      if (isset($definition['aliases'])) {
        $rows = [];
        // Iterating over all the aliases.
        foreach ($definition['aliases'] as $alias) {
          $rows[] = $alias;
        }
        // Aliases render array.
        $section[$command][] = [
          '#markup' => '<div id="aliases">' . t('Aliases') . '</div>',
        ];
        // List of aliases.
        $section[$command]['aliases'] = [
          '#theme' => 'item_list',
          '#items' => $rows,
          '#context' => ['list_style' => 'comma-list'],
        ];
      }
    }
    // Attaching css styles.
    $section[$command]['aliases']['#attached']['library'][] = 'drush_help/help_page';
    // Rendering all the elements.
    $drush_command_html = \Drupal::service('renderer')->render($section);

    return $drush_command_html;
  }

}
